package com.ruoyi.web.controller.cp;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.annotation.Anonymous;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.CpsFileReviewInfo;
import com.ruoyi.system.service.ICpsFileReviewInfoService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * cps_file_review_info预览文件Controller
 *
 * @author ruoyi
 * @date 2024-08-14
 */
@RestController
@CrossOrigin
@Anonymous
@RequestMapping("/cp/fileInfo")
public class CpsFileReviewInfoController extends BaseController
{
    @Autowired
    private ICpsFileReviewInfoService cpsFileReviewInfoService;

    /**
     * 查询cps_file_review_info预览文件列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CpsFileReviewInfo cpsFileReviewInfo)
    {
        startPage();
        List<CpsFileReviewInfo> list = cpsFileReviewInfoService.selectCpsFileReviewInfoList(cpsFileReviewInfo);
        return getDataTable(list);
    }

    /**
     * 导出cps_file_review_info预览文件列表
     */
    @Log(title = "cps_file_review_info预览文件", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CpsFileReviewInfo cpsFileReviewInfo)
    {
        List<CpsFileReviewInfo> list = cpsFileReviewInfoService.selectCpsFileReviewInfoList(cpsFileReviewInfo);
        ExcelUtil<CpsFileReviewInfo> util = new ExcelUtil<CpsFileReviewInfo>(CpsFileReviewInfo.class);
        util.exportExcel(response, list, "cps_file_review_info预览文件数据");
    }

    /**
     * 获取cps_file_review_info预览文件详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(cpsFileReviewInfoService.selectCpsFileReviewInfoById(id));
    }

    /**
     * 新增cps_file_review_info预览文件
     */
    @Log(title = "cps_file_review_info预览文件", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CpsFileReviewInfo cpsFileReviewInfo)
    {
        return toAjax(cpsFileReviewInfoService.insertCpsFileReviewInfo(cpsFileReviewInfo));
    }

    /**
     * 修改cps_file_review_info预览文件
     */
    @Log(title = "cps_file_review_info预览文件", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CpsFileReviewInfo cpsFileReviewInfo)
    {
        return toAjax(cpsFileReviewInfoService.updateCpsFileReviewInfo(cpsFileReviewInfo));
    }

    /**
     * 删除cps_file_review_info预览文件
     */
    @Log(title = "cps_file_review_info预览文件", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(cpsFileReviewInfoService.deleteCpsFileReviewInfoByIds(ids));
    }
}
